@@ -2,7 +2,8 @@
 #' 
 #' Reads and parses the header of a raw data file as output by the server
 #' running on a Raspberry Pi board to extract the whole header remark field. The
-#' time field is retrieved and decoded.
+#' time field is retrieved and decoded. 
+#' The company formerly named Ocean Optics is now called Ocean Insight.
 #' 
 #' @param file character string
 #' @param date a \code{POSIXct} object to use to set the \code{"when.measured"}
@@ -25,17 +26,33 @@
 #' @return A raw_spct object.
 #' 
 #' @export
-#' @references \url{https://www.r4photobiology.info} \url{https://oceanoptics.com/} \url{https://www.raspberrypi.org/}
 #' 
-#' @note The header in these files has very little information, so the user
-#' needs to supply the number of pixels in the array as well as the date-time.
+#' @references \url{https://www.oceaninsight.com/} \url{https://www.raspberrypi.org/}
+#' 
+#' @note The header in these files has very little information.
 #' The file contains a time in milliseconds but as the Raspberry Pi board
 #' contains no real-time clock, it seems to default to number of milliseconds
-#' since the Pi was switched on. If no argument is passed to date this
-#' attribute is set to the file modification date obtained with file.mtime().
+#' since the Pi was switched on. The user may wish to supply the date-time as
+#' an argument, but if no argument is passed to \code{date} this
+#' attribute is set to the file modification date obtained with \code{file.mtime()}.
 #' This date-time gives an upper limit to the real time of measurement as in
 #' some operating systems it is reset when the file is copied or even without
-#' any good apparent reason.
+#' any good apparent reason. The user may need to supply the number of pixels 
+#' in the array although the default of \code{npixels = Inf} usually works
+#' and triggers no warnings.
+#' 
+#' @examples
+#' 
+#'  file.name <- 
+#'    system.file("extdata", "spectrum.pi", 
+#'                package = "photobiologyInOut", mustWork = TRUE)
+#'                 
+#'  oopi.spct <- read_oo_pidata(file = file.name)
+#'  
+#'  oopi.spct
+#'  getWhenMeasured(oopi.spct)
+#'  getWhatMeasured(oopi.spct)
+#'  cat(comment(oopi.spct))
 #' 
 read_oo_pidata <- function(file,
                            date = NULL,
@@ -43,7 +60,7 @@ read_oo_pidata <- function(file,
                            label = NULL,
                            tz = NULL,
                            locale = readr::default_locale(),
-                           npixels = 2048,
+                           npixels = Inf,
                            spectrometer.sn = "FLMS00673") {
   if (is.null(tz)) {
     tz <- locale$tz
@@ -57,12 +74,14 @@ read_oo_pidata <- function(file,
   }
   
   first.line <- scan(file = file, nlines = 1, 
-                     skip = 0, what = "character", sep = "\n")
+                     skip = 0, what = "character", 
+                     sep = "\n", quiet = TRUE)
   
   skip.n <- ifelse(grepl("sequence", first.line), 1L, 0L)
   
   file_header <- scan(file = file, nlines = 4, 
-                      skip = skip.n, what = "character", sep = "\n")
+                      skip = skip.n, what = "character", 
+                      sep = "\n", quiet = TRUE)
   NonASCII <- tools::showNonASCII(file_header)
   if (length(NonASCII) > 0L) {
     warning("Found non-ASCII characters in file header: ", 
@@ -124,6 +143,7 @@ read_oo_pidata <- function(file,
     skip = 5 + skip.n,
     n_max = npixels,
     col_types = readr::cols(),
+    progress = FALSE,
     locale = locale
   )
   
